/* stabile_Umkreisung.rexx
 *
 * Autor: Thies Wellpott
 * Version: 1.1 (14.6.94)
 *
 * Berechnet fr GraviSimu fr einen definierbaren Zentralkrper und
 * einen durch verschiedene, whlbare Parameter definierbaren
 * Satelliten eine nach physikalischen Gesetzen stabile Kreisbahn
 *
 * bentigt rexxmathlib.library
 */

G = 6.67259e-11         /* Gravitationskonstante */
PI = 3.1415927

Call Addlib("rexxmathlib.library",0,-30,0)

Options Prompt ">> "

Say "Berechnet die Werte fr eine stabile Umkreisung eines"
Say "einzugebenes Objektes um ein anderes einzugebenes."
Say
Say "Geben Sie den Namen des zentralen Objektes ein"
Parse Pull obj1name
Say "Geben Sie die Masse des zentralen Objektes in kg ein"
Parse Pull obj1m obj1m_einh
Say
Say "Geben Sie den Namen des umkreisenden Objektes ein"
Parse Pull obj2name
Say "Geben Sie die Masse des umkreisenden Objektes in kg ein (mu"
Say "wesentlich kleiner als die Masse des zentralen Objektes sein)"
Parse Pull obj2m obj2m_einh
Say "Welchen Wert wollen Sie fr das umkreisende Objekt eingeben?"
Say "  1: Radius   2: Umlaufdauer   3: Winkelgeschwindigkeit"
Say "  4: Geschwindigkeit"
Parse Pull x

SELECT
   WHEN x = "1" THEN
   DO
      Say "Geben Sie den Umkreisungsradius in m ein"
      Parse Pull r

      v = Sqrt(G * obj1m / r)
   END /* 1 */


   WHEN x = "2" THEN
   DO
      Say "Geben Sie die Umlaufdauer in s ein"
      Parse Pull T

      r = Pow(G * obj1m * T*T / (4*PI*PI), 1/3)
      v = 2*PI * r / T
   END /* 2 */


   WHEN x = "3" THEN
   DO
      Say "Geben Sie die Winkelgeschwindigkeit in Grad/s ein"
      Parse Pull w

      w = w * PI/180             /* Grad in Radiant */
      r = Pow(G * obj1m / (w*w), 1/3)
      v = w * r
   END /* 3 */


   WHEN x = "4" THEN
   DO
      Say "Geben Sie die Geschwindigkeit in m/s ein"
      Parse Pull v

      r = G * obj1m / (v*v)
   END /* 4 */


   OTHERWISE
      Say
      Say "Ungltige Eingabe!"
      Exit
END /* SELECT */

Say

DO WHILE ~Show("Ports", "GRAVISIMU.1")
   Say "GraviSimu ist nicht gestartet!"
   Options Prompt "[E]nde oder noch einmal probieren (andere Taste)? "
   Pull antw
   IF antw = "E" THEN
      Exit
END /* WHILE */

Address "GRAVISIMU.1"

Options Results
'GetNumObjects'
IF Result ~= 0 THEN
   Say "*** Achtung! Es sind noch Objekte vorhanden; diese knnen stren!"
Options Results OFF

'NewObject "'obj1name'"' obj1m 'kg 0 0 m 0 0 m/s 1 1 0 1'
IF RC ~= 0 THEN
DO
   Say '*** Konnte Objekt 1 "'obj1name'" nicht anfgen!'
   Exit
END

'NewObject "'obj2name'"' obj2m 'kg' r '0 m 0' v 'm/s 1 1 1 1'
IF RC ~= 0 THEN                  
DO
   Say '*** Konnte Objekt 2 "'obj2name'" nicht anfgen!'
   Exit
END

'SetScale' r/100 'm'             /* => Radius entspricht 100 Pixeln */
'SetTime' 2*PI * r/v/750 's'     /* 750 Pos. pro Umlauf */

Exit

